==> deepin-calculator_5.7.12.orig.tar.gz: deepin-calculator-5.7.12/translations/deepin-calculator_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有内存</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>清除历史记录</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>计算器</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>标准</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>科学</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>计算器是一款简单易用的桌面计算器，支持标准型、科学型、程序员型模式。</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>程序员</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>清除内存项</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有内存</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>内存重新调用</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到内存项</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>内存增加</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>从内存项中减掉</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>内存减少</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>内存存储</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>清除内存项</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到内存项</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>从内存项中减掉</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>内存中没有数据</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算数移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>逻辑移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循环移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>带进位循环移位</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算数移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>逻辑移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循环移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>带进位循环移位</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>计算器</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>历史记录</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>无历史记录</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.4.orig.tar.gz: deepin-calculator-6.5.4/translations/deepin-calculator_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有内存</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>清除历史记录</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>切换为千分位</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>切换为万分位</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>计算器</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>标准</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>科学</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>计算器是一款简单易用的桌面计算器，支持标准型、科学型、程序员型模式。</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>程序员</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>清除内存项</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有内存</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>内存重新调用</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到内存项</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>内存增加</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>从内存项中减掉</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>内存减少</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>内存存储</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>清除内存项</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到内存项</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>从内存项中减掉</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>内存中没有数据</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算数移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>逻辑移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循环移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>带进位循环移位</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算数移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>逻辑移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循环移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>带进位循环移位</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>计算器</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>历史记录</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>无历史记录</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
</TS>
